==> haskell-xdg-desktop-entry-0.1.1.2-138.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-xdg-desktop-entry.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 xdg-desktop-entry
version:              0.1.1.2
visibility:           public
id:                   xdg-desktop-entry-0.1.1.2-D2R1cTyoZZE4doVke6hSpE
key:                  xdg-desktop-entry-0.1.1.2-D2R1cTyoZZE4doVke6hSpE
license:              BSD-3-Clause
maintainer:           IvanMalison@gmail.com
author:               Ivan Malison
homepage:             https://github.com/taffybar/xdg-desktop-entry
synopsis:             Parse files conforming to the xdg desktop entry spec
description:          Parse files conforming to the xdg desktop entry spec.
category:             System
abi:                  cc0ced482443eba7cee821db4209fe72
exposed:              True
exposed-modules:      System.Environment.XDG.DesktopEntry
import-dirs:          /usr/lib/ghc-9.6.6/site-local/xdg-desktop-entry-0.1.1.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/xdg-desktop-entry-0.1.1.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/xdg-desktop-entry-0.1.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-xdg-desktop-entry
hs-libraries:         HSxdg-desktop-entry-0.1.1.2-D2R1cTyoZZE4doVke6hSpE
depends:
    base-4.18.2.1 directory-1.3.8.5 either-5.0.3-LXBywpYsrH13GkjtmaGjK1
    filepath-1.4.300.1 ini-0.4.2-13Nwba0BN2Y17jOOEO0UfW
    multimap-1.2.1-4W8aWHvVl9g78Tpaptjwyw
    safe-0.3.21-6ywRAlXnRFuBscoqJeUz3o text-2.0.2 transformers-0.6.1.0
    unix-2.8.4.0 unordered-containers-0.2.20.1-50qrTxmoJy9AxZ7OdMnycu

haddock-interfaces:
    /usr/share/doc/haskell-xdg-desktop-entry/html/xdg-desktop-entry.haddock

haddock-html:         /usr/share/doc/haskell-xdg-desktop-entry/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-xdg-desktop-entry-0.1.1.2-139-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-xdg-desktop-entry.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 xdg-desktop-entry
version:              0.1.1.2
visibility:           public
id:                   xdg-desktop-entry-0.1.1.2-AzHV7LKosilEOFU76W0iYh
key:                  xdg-desktop-entry-0.1.1.2-AzHV7LKosilEOFU76W0iYh
license:              BSD-3-Clause
maintainer:           IvanMalison@gmail.com
author:               Ivan Malison
homepage:             https://github.com/taffybar/xdg-desktop-entry
synopsis:             Parse files conforming to the xdg desktop entry spec
description:          Parse files conforming to the xdg desktop entry spec.
category:             System
abi:                  cd83ad74366e43400c3108a0d2e97806
exposed:              True
exposed-modules:      System.Environment.XDG.DesktopEntry
import-dirs:          /usr/lib/ghc-9.6.6/site-local/xdg-desktop-entry-0.1.1.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/xdg-desktop-entry-0.1.1.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/xdg-desktop-entry-0.1.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-xdg-desktop-entry
hs-libraries:         HSxdg-desktop-entry-0.1.1.2-AzHV7LKosilEOFU76W0iYh
depends:
    base-4.18.2.1 directory-1.3.8.5 either-5.0.3-AwsJObJJa5t15rwL7Wjn2s
    filepath-1.4.300.1 ini-0.4.2-CzH5cgvXkfKJT0UR2lY8Qv
    multimap-1.2.1-4W8aWHvVl9g78Tpaptjwyw
    safe-0.3.21-7oQO4KcgDWt1YhK3ifcAwa text-2.0.2 transformers-0.6.1.0
    unix-2.8.4.0 unordered-containers-0.2.20.1-L0jiELAFLwP1g4FZscm3B5

haddock-interfaces:
    /usr/share/doc/haskell-xdg-desktop-entry/html/xdg-desktop-entry.haddock

haddock-html:         /usr/share/doc/haskell-xdg-desktop-entry/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
